@@ -219,7 +219,10 @@ class expose:
     """
     a decorator that applies the result of the function to the provided template
     """
-    self._template=template
+    if type(template) is type:
+      self._template=template(*templateArgs,**templateKw)
+    else:
+      self._template=template
     self._templateArgs=templateArgs
     self._templateKw=templateKw
     self._response=responseCode
@@ -456,8 +459,10 @@ class baseWebApp:
       f=self._root
       a=rq.uriList
     try: r=f(rq, *a)
+    except (KeyboardInterrupt, SystemExit, MemoryError): raise
     except webAppBaseException as e:
       return self._handleException(rq, e)
+    #TODO: treat any other exception as 500
     return r
 
   @expose()
